@@ -1,16 +1,17 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.566-2-g7f6ebb36
+package JSON::Schema::Modern; # git description: v0.567-6-gefad9f95
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.567';
+our $VERSION = '0.568';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
 use strictures 2;
-use experimental qw(signatures postderef);
+use stable 0.031 'postderef';
+use experimental 'signatures';
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
@@ -944,8 +945,23 @@ has _media_type => (
     +{
       (map +($_ => $_json_media_type),
         qw(application/json application/schema+json application/schema-instance+json)),
-      map +($_ => sub ($content_ref) { $content_ref }),
-        qw(text/* application/octet-stream),
+      (map +($_ => sub ($content_ref) { $content_ref }),
+        qw(text/* application/octet-stream)),
+      'application/x-www-form-urlencoded' => sub ($content_ref) {
+        \ Mojo::Parameters->new->charset('UTF-8')->parse($content_ref->$*)->to_hash;
+      },
+      'application/x-ndjson' => sub ($content_ref) {
+        my $decoder = JSON::MaybeXS->new(allow_nonref => 1, utf8 => 1);
+        my $line = 0; # line numbers start at 1
+        \[ map {
+            do {
+              try { ++$line; $decoder->decode($_) }
+              catch ($e) { die 'parse error at line '.$line.': '.$e }
+            }
+          }
+          split(/\r?\n/, $content_ref->$*)
+        ];
+      },
     };
   },
 );
@@ -1022,7 +1038,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.567
+version 0.568
 
 =head1 SYNOPSIS
 
@@ -1411,6 +1427,14 @@ C<application/octet-stream> - passes strings through unchanged
 
 =item *
 
+C<application/x-www-form-urlencoded>
+
+=item *
+
+C<application/x-ndjson> - see L<https://github.com/ndjson/ndjson-spec>
+
+=item *
+
 C<text/*> - passes strings through unchanged
 
 =back
